@@ -100,15 +100,15 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_codecommit
-import aws_cdk.aws_ec2
-import aws_cdk.core
-import constructs
+import aws_cdk.aws_codecommit as _aws_cdk_aws_codecommit_692dd32c
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_67de8e8d
+import aws_cdk.core as _aws_cdk_core_f4b25747
+import constructs as _constructs_77d1e7e8
 
 
-@jsii.implements(aws_cdk.core.IInspectable)
+@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
 class CfnEnvironmentEC2(
-    aws_cdk.core.CfnResource,
+    _aws_cdk_core_f4b25747.CfnResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-cloud9.CfnEnvironmentEC2",
 ):
@@ -150,7 +150,7 @@ class CfnEnvironmentEC2(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: _aws_cdk_core_f4b25747.Construct,
         id: builtins.str,
         *,
         instance_type: builtins.str,
@@ -160,9 +160,9 @@ class CfnEnvironmentEC2(
         image_id: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         owner_arn: typing.Optional[builtins.str] = None,
-        repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union["CfnEnvironmentEC2.RepositoryProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
+        repositories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[typing.Union["CfnEnvironmentEC2.RepositoryProperty", typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]]]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Create a new ``AWS::Cloud9::EnvironmentEC2``.
 
@@ -180,23 +180,7 @@ class CfnEnvironmentEC2(
         :param tags: An array of key-value pairs that will be associated with the new AWS Cloud9 development environment.
         '''
         if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                instance_type: builtins.str,
-                automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
-                connection_type: typing.Optional[builtins.str] = None,
-                description: typing.Optional[builtins.str] = None,
-                image_id: typing.Optional[builtins.str] = None,
-                name: typing.Optional[builtins.str] = None,
-                owner_arn: typing.Optional[builtins.str] = None,
-                repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
-                subnet_id: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7ef001bf4de14efb43e2f14efb064bafe67bf100ece9581c3443b457e29c412d)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnEnvironmentEC2Props(
@@ -215,15 +199,13 @@ class CfnEnvironmentEC2(
         jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
-    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
         '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fa7f42337ef2529ba5ebec429c25e2db3649fee8e55e44712602de4ac9e41d2d)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -236,9 +218,7 @@ class CfnEnvironmentEC2(
         :param props: -
         '''
         if __debug__:
-            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3f6f92dd2830861bf1bd59423ebfb32c8279709b743cdd6e14723ba3cfc63475)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -273,12 +253,12 @@ class CfnEnvironmentEC2(
 
     @builtins.property
     @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.core.TagManager:
+    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
         '''An array of key-value pairs that will be associated with the new AWS Cloud9 development environment.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-tags
         '''
-        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
+        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))
 
     @builtins.property
     @jsii.member(jsii_name="instanceType")
@@ -292,9 +272,7 @@ class CfnEnvironmentEC2(
     @instance_type.setter
     def instance_type(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fee3b5ffb534e9db1b863f88e365316c39cf5af4ecba3abb686a8f2d3698dc31)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceType", value)
 
@@ -310,9 +288,7 @@ class CfnEnvironmentEC2(
     @automatic_stop_time_minutes.setter
     def automatic_stop_time_minutes(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[jsii.Number]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7bfacb916666563965d17d0d6b97cc3bd1f4960a91b8865a25f52898b3e0c083)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "automaticStopTimeMinutes", value)
 
@@ -330,9 +306,7 @@ class CfnEnvironmentEC2(
     @connection_type.setter
     def connection_type(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__17a8539e2d0dabd697b9787fd831ce368932946e7631809fb174a07fb2ff2d88)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionType", value)
 
@@ -348,9 +322,7 @@ class CfnEnvironmentEC2(
     @description.setter
     def description(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f17f0ad701068ea3f26386011592c6495cda01463205ee6833a91635a0bb8d20)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -382,9 +354,7 @@ class CfnEnvironmentEC2(
     @image_id.setter
     def image_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a8b727883922a845604ced8dfc1e9457b4e92f6ec4074ff651699afed670cdf3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageId", value)
 
@@ -400,9 +370,7 @@ class CfnEnvironmentEC2(
     @name.setter
     def name(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1a11fd8c6369ae96dba8413bab23048418689b507e734a18714e4f37d2be186f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -420,9 +388,7 @@ class CfnEnvironmentEC2(
     @owner_arn.setter
     def owner_arn(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e1696f3784c2082c0a42062fd11bc8a4e1ae04790e629f13939aa8e8d3494de3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ownerArn", value)
 
@@ -430,24 +396,20 @@ class CfnEnvironmentEC2(
     @jsii.member(jsii_name="repositories")
     def repositories(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", aws_cdk.core.IResolvable]]]]:
+    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _aws_cdk_core_f4b25747.IResolvable]]]]:
         '''Any AWS CodeCommit source code repositories to be cloned into the development environment.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
         '''
-        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", aws_cdk.core.IResolvable]]]], jsii.get(self, "repositories"))
+        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _aws_cdk_core_f4b25747.IResolvable]]]], jsii.get(self, "repositories"))
 
     @repositories.setter
     def repositories(
         self,
-        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", aws_cdk.core.IResolvable]]]],
+        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _aws_cdk_core_f4b25747.IResolvable]]]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, aws_cdk.core.IResolvable]]]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__80c2c1692b3309dae9ac320a2c92999f53ab1bc244bf04c509c2c2cc93cb78e9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositories", value)
 
@@ -463,9 +425,7 @@ class CfnEnvironmentEC2(
     @subnet_id.setter
     def subnet_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__37ab8081309b904e48eadc4d411e6e149b0e34b57934043c490b878e782edbdc)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "subnetId", value)
 
@@ -504,16 +464,10 @@ class CfnEnvironmentEC2(
                 )
             '''
             if __debug__:
-                def stub(
-                    *,
-                    path_component: builtins.str,
-                    repository_url: builtins.str,
-                ) -> None:
-                    ...
-                type_hints = typing.get_type_hints(stub)
+                type_hints = typing.get_type_hints(_typecheckingstub__345d4f5e55d88315961d456d5b4e9e28e6cc5882d70b8f9f79eff8e139cae234)
                 check_type(argname="argument path_component", value=path_component, expected_type=type_hints["path_component"])
                 check_type(argname="argument repository_url", value=repository_url, expected_type=type_hints["repository_url"])
-            self._values: typing.Dict[str, typing.Any] = {
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "path_component": path_component,
                 "repository_url": repository_url,
             }
@@ -581,9 +535,9 @@ class CfnEnvironmentEC2Props:
         image_id: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         owner_arn: typing.Optional[builtins.str] = None,
-        repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
+        repositories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]]]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``CfnEnvironmentEC2``.
 
@@ -629,21 +583,7 @@ class CfnEnvironmentEC2Props:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                instance_type: builtins.str,
-                automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
-                connection_type: typing.Optional[builtins.str] = None,
-                description: typing.Optional[builtins.str] = None,
-                image_id: typing.Optional[builtins.str] = None,
-                name: typing.Optional[builtins.str] = None,
-                owner_arn: typing.Optional[builtins.str] = None,
-                repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
-                subnet_id: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__77c82c4a8b3b96c7c641defd2e0263a0566263d37ff96b2b62ad4068f2f26b12)
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
             check_type(argname="argument automatic_stop_time_minutes", value=automatic_stop_time_minutes, expected_type=type_hints["automatic_stop_time_minutes"])
             check_type(argname="argument connection_type", value=connection_type, expected_type=type_hints["connection_type"])
@@ -654,7 +594,7 @@ class CfnEnvironmentEC2Props:
             check_type(argname="argument repositories", value=repositories, expected_type=type_hints["repositories"])
             check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "instance_type": instance_type,
         }
         if automatic_stop_time_minutes is not None:
@@ -763,13 +703,13 @@ class CfnEnvironmentEC2Props:
     @builtins.property
     def repositories(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, aws_cdk.core.IResolvable]]]]:
+    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, _aws_cdk_core_f4b25747.IResolvable]]]]:
         '''Any AWS CodeCommit source code repositories to be cloned into the development environment.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
         '''
         result = self._values.get("repositories")
-        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, aws_cdk.core.IResolvable]]]], result)
+        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, _aws_cdk_core_f4b25747.IResolvable]]]], result)
 
     @builtins.property
     def subnet_id(self) -> typing.Optional[builtins.str]:
@@ -781,13 +721,13 @@ class CfnEnvironmentEC2Props:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def tags(self) -> typing.Optional[typing.List[aws_cdk.core.CfnTag]]:
+    def tags(self) -> typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]]:
         '''An array of key-value pairs that will be associated with the new AWS Cloud9 development environment.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-tags
         '''
         result = self._values.get("tags")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.core.CfnTag]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -838,7 +778,7 @@ class CloneRepository(
     @builtins.classmethod
     def from_code_commit(
         cls,
-        repository: aws_cdk.aws_codecommit.IRepository,
+        repository: _aws_cdk_aws_codecommit_692dd32c.IRepository,
         path: builtins.str,
     ) -> "CloneRepository":
         '''(experimental) import repository to cloud9 environment from AWS CodeCommit.
@@ -849,12 +789,7 @@ class CloneRepository(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                repository: aws_cdk.aws_codecommit.IRepository,
-                path: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__483a1f3243fb459efb95656bb9b5fc471788e4e5976dc317cc78dc8983cc3b93)
             check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         return typing.cast("CloneRepository", jsii.sinvoke(cls, "fromCodeCommit", [repository, path]))
@@ -912,13 +847,13 @@ class Ec2EnvironmentProps:
     def __init__(
         self,
         *,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        vpc: _aws_cdk_aws_ec2_67de8e8d.IVpc,
         cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
         connection_type: typing.Optional[ConnectionType] = None,
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        subnet_selection: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.InstanceType] = None,
+        subnet_selection: typing.Optional[typing.Union[_aws_cdk_aws_ec2_67de8e8d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) Properties for Ec2Environment.
 
@@ -958,20 +893,9 @@ class Ec2EnvironmentProps:
             CfnOutput(self, "URL", value=c9env.ide_url)
         '''
         if isinstance(subnet_selection, dict):
-            subnet_selection = aws_cdk.aws_ec2.SubnetSelection(**subnet_selection)
+            subnet_selection = _aws_cdk_aws_ec2_67de8e8d.SubnetSelection(**subnet_selection)
         if __debug__:
-            def stub(
-                *,
-                vpc: aws_cdk.aws_ec2.IVpc,
-                cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
-                connection_type: typing.Optional[ConnectionType] = None,
-                description: typing.Optional[builtins.str] = None,
-                ec2_environment_name: typing.Optional[builtins.str] = None,
-                instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-                subnet_selection: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f03edf2a3832eda1f1e0f29061da4f3377d1e509902169bcdd15d440a645268b)
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument cloned_repositories", value=cloned_repositories, expected_type=type_hints["cloned_repositories"])
             check_type(argname="argument connection_type", value=connection_type, expected_type=type_hints["connection_type"])
@@ -979,7 +903,7 @@ class Ec2EnvironmentProps:
             check_type(argname="argument ec2_environment_name", value=ec2_environment_name, expected_type=type_hints["ec2_environment_name"])
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
             check_type(argname="argument subnet_selection", value=subnet_selection, expected_type=type_hints["subnet_selection"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "vpc": vpc,
         }
         if cloned_repositories is not None:
@@ -996,14 +920,14 @@ class Ec2EnvironmentProps:
             self._values["subnet_selection"] = subnet_selection
 
     @builtins.property
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
+    def vpc(self) -> _aws_cdk_aws_ec2_67de8e8d.IVpc:
         '''(experimental) The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
 
         :stability: experimental
         '''
         result = self._values.get("vpc")
         assert result is not None, "Required property 'vpc' is missing"
-        return typing.cast(aws_cdk.aws_ec2.IVpc, result)
+        return typing.cast(_aws_cdk_aws_ec2_67de8e8d.IVpc, result)
 
     @builtins.property
     def cloned_repositories(self) -> typing.Optional[typing.List[CloneRepository]]:
@@ -1052,7 +976,7 @@ class Ec2EnvironmentProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def instance_type(self) -> typing.Optional[aws_cdk.aws_ec2.InstanceType]:
+    def instance_type(self) -> typing.Optional[_aws_cdk_aws_ec2_67de8e8d.InstanceType]:
         '''(experimental) The type of instance to connect to the environment.
 
         :default: - t2.micro
@@ -1060,10 +984,12 @@ class Ec2EnvironmentProps:
         :stability: experimental
         '''
         result = self._values.get("instance_type")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.InstanceType], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_67de8e8d.InstanceType], result)
 
     @builtins.property
-    def subnet_selection(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetSelection]:
+    def subnet_selection(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetSelection]:
         '''(experimental) The subnetSelection of the VPC that AWS Cloud9 will use to communicate with the Amazon EC2 instance.
 
         :default: - all public subnets of the VPC are selected.
@@ -1071,7 +997,7 @@ class Ec2EnvironmentProps:
         :stability: experimental
         '''
         result = self._values.get("subnet_selection")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetSelection], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetSelection], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1086,7 +1012,7 @@ class Ec2EnvironmentProps:
 
 
 @jsii.interface(jsii_type="@aws-cdk/aws-cloud9.IEc2Environment")
-class IEc2Environment(aws_cdk.core.IResource, typing_extensions.Protocol):
+class IEc2Environment(_aws_cdk_core_f4b25747.IResource, typing_extensions.Protocol):
     '''(experimental) A Cloud9 Environment.
 
     :stability: experimental
@@ -1114,7 +1040,7 @@ class IEc2Environment(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _IEc2EnvironmentProxy(
-    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
+    jsii.proxy_for(_aws_cdk_core_f4b25747.IResource), # type: ignore[misc]
 ):
     '''(experimental) A Cloud9 Environment.
 
@@ -1149,7 +1075,7 @@ typing.cast(typing.Any, IEc2Environment).__jsii_proxy_class__ = lambda : _IEc2En
 
 @jsii.implements(IEc2Environment)
 class Ec2Environment(
-    aws_cdk.core.Resource,
+    _aws_cdk_core_f4b25747.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-cloud9.Ec2Environment",
 ):
@@ -1186,16 +1112,16 @@ class Ec2Environment(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        vpc: _aws_cdk_aws_ec2_67de8e8d.IVpc,
         cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
         connection_type: typing.Optional[ConnectionType] = None,
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        subnet_selection: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.InstanceType] = None,
+        subnet_selection: typing.Optional[typing.Union[_aws_cdk_aws_ec2_67de8e8d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -1211,20 +1137,7 @@ class Ec2Environment(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                vpc: aws_cdk.aws_ec2.IVpc,
-                cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
-                connection_type: typing.Optional[ConnectionType] = None,
-                description: typing.Optional[builtins.str] = None,
-                ec2_environment_name: typing.Optional[builtins.str] = None,
-                instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-                subnet_selection: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f27b9bc1933f9777b5adf61191c8d6dc90e2bc95f3e74b10141065c99796107c)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = Ec2EnvironmentProps(
@@ -1243,7 +1156,7 @@ class Ec2Environment(
     @builtins.classmethod
     def from_ec2_environment_name(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         ec2_environment_name: builtins.str,
     ) -> IEc2Environment:
@@ -1256,13 +1169,7 @@ class Ec2Environment(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                ec2_environment_name: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__11b50ad064b61920cd122a41272fcef73632116c65c26761f3751a269e4c0504)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument ec2_environment_name", value=ec2_environment_name, expected_type=type_hints["ec2_environment_name"])
@@ -1308,12 +1215,12 @@ class Ec2Environment(
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
+    def vpc(self) -> _aws_cdk_aws_ec2_67de8e8d.IVpc:
         '''(experimental) VPC ID.
 
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
+        return typing.cast(_aws_cdk_aws_ec2_67de8e8d.IVpc, jsii.get(self, "vpc"))
 
 
 __all__ = [
@@ -1327,3 +1234,154 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__7ef001bf4de14efb43e2f14efb064bafe67bf100ece9581c3443b457e29c412d(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    id: builtins.str,
+    *,
+    instance_type: builtins.str,
+    automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
+    connection_type: typing.Optional[builtins.str] = None,
+    description: typing.Optional[builtins.str] = None,
+    image_id: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    owner_arn: typing.Optional[builtins.str] = None,
+    repositories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]]]] = None,
+    subnet_id: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fa7f42337ef2529ba5ebec429c25e2db3649fee8e55e44712602de4ac9e41d2d(
+    inspector: _aws_cdk_core_f4b25747.TreeInspector,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3f6f92dd2830861bf1bd59423ebfb32c8279709b743cdd6e14723ba3cfc63475(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fee3b5ffb534e9db1b863f88e365316c39cf5af4ecba3abb686a8f2d3698dc31(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7bfacb916666563965d17d0d6b97cc3bd1f4960a91b8865a25f52898b3e0c083(
+    value: typing.Optional[jsii.Number],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__17a8539e2d0dabd697b9787fd831ce368932946e7631809fb174a07fb2ff2d88(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f17f0ad701068ea3f26386011592c6495cda01463205ee6833a91635a0bb8d20(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a8b727883922a845604ced8dfc1e9457b4e92f6ec4074ff651699afed670cdf3(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1a11fd8c6369ae96dba8413bab23048418689b507e734a18714e4f37d2be186f(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e1696f3784c2082c0a42062fd11bc8a4e1ae04790e629f13939aa8e8d3494de3(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__80c2c1692b3309dae9ac320a2c92999f53ab1bc244bf04c509c2c2cc93cb78e9(
+    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, _aws_cdk_core_f4b25747.IResolvable]]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__37ab8081309b904e48eadc4d411e6e149b0e34b57934043c490b878e782edbdc(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__345d4f5e55d88315961d456d5b4e9e28e6cc5882d70b8f9f79eff8e139cae234(
+    *,
+    path_component: builtins.str,
+    repository_url: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__77c82c4a8b3b96c7c641defd2e0263a0566263d37ff96b2b62ad4068f2f26b12(
+    *,
+    instance_type: builtins.str,
+    automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
+    connection_type: typing.Optional[builtins.str] = None,
+    description: typing.Optional[builtins.str] = None,
+    image_id: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    owner_arn: typing.Optional[builtins.str] = None,
+    repositories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]]]] = None,
+    subnet_id: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__483a1f3243fb459efb95656bb9b5fc471788e4e5976dc317cc78dc8983cc3b93(
+    repository: _aws_cdk_aws_codecommit_692dd32c.IRepository,
+    path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f03edf2a3832eda1f1e0f29061da4f3377d1e509902169bcdd15d440a645268b(
+    *,
+    vpc: _aws_cdk_aws_ec2_67de8e8d.IVpc,
+    cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+    connection_type: typing.Optional[ConnectionType] = None,
+    description: typing.Optional[builtins.str] = None,
+    ec2_environment_name: typing.Optional[builtins.str] = None,
+    instance_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.InstanceType] = None,
+    subnet_selection: typing.Optional[typing.Union[_aws_cdk_aws_ec2_67de8e8d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f27b9bc1933f9777b5adf61191c8d6dc90e2bc95f3e74b10141065c99796107c(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    vpc: _aws_cdk_aws_ec2_67de8e8d.IVpc,
+    cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+    connection_type: typing.Optional[ConnectionType] = None,
+    description: typing.Optional[builtins.str] = None,
+    ec2_environment_name: typing.Optional[builtins.str] = None,
+    instance_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.InstanceType] = None,
+    subnet_selection: typing.Optional[typing.Union[_aws_cdk_aws_ec2_67de8e8d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__11b50ad064b61920cd122a41272fcef73632116c65c26761f3751a269e4c0504(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    ec2_environment_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
